@@ -512,6 +512,7 @@ async def get_cluster_users(
             with_user_info=True,
             org_name=org,
         )
+        users = sorted(users, key=lambda user: (user.user_name, user.org_name or ""))
     with root.pager():
         root.print(fmt(users))
 
@@ -1128,6 +1129,9 @@ async def remove_org(root: Root, org_name: str, force: bool) -> None:
 
     Completely removes org from the system.
     """
+    orgs = await root.client._admin.list_orgs()
+    if not any(org.name == org_name for org in orgs):
+        raise ValueError(f"Organization '{org_name}' is not found.")
 
     if not force:
         with patch_stdout():
