@@ -24,6 +24,7 @@ import neuro_cli
 from . import file_logging
 from .alias import find_alias
 from .asyncio_utils import setup_child_watcher
+from .click_types import setup_shell_completion
 from .const import (
     EX_DATAERR,
     EX_IOERR,
@@ -302,7 +303,6 @@ CMD_MAP = {
     # groups
     "admin": "neuro_cli.admin:admin",
     "job": "neuro_cli.job:job",
-    "project": "neuro_cli.project:project",
     "storage": "neuro_cli.storage:storage",
     "image": "neuro_cli.image:image",
     "config": "neuro_cli.config:config",
@@ -549,6 +549,8 @@ def _err_to_str(err: Exception) -> str:
 
 
 def main(args: Optional[List[str]] = None) -> None:
+    setup_shell_completion()
+
     try:
         with warnings.catch_warnings():
             warnings.simplefilter("ignore", ResourceWarning)
